@@ -111,7 +111,7 @@ class DataTable(WidgetWrapper):
                                 containerClassId=self.el_class_id,
                                 tableId=self.table_id,
                                 tunnelId=self.tunnel.tunnel_id,
-                                columns=ujson.dumps(columns),
+                                columns=ujson.dumps(self.columns),
                                 table_class=self.table_class,
                                 options=ujson.dumps(self.options))
 
